<a id="mypy-boto3-kafkaconnect"></a>

# mypy-boto3-kafkaconnect

[![PyPI - mypy-boto3-kafkaconnect](https://img.shields.io/pypi/v/mypy-boto3-kafkaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-kafkaconnect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kafkaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-kafkaconnect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-kafkaconnect?color=blue)](https://pypistats.org/packages/mypy-boto3-kafkaconnect)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.KafkaConnect 1.19.10](https://boto3.amazonaws.com/v1/documentation/api/1.19.10/reference/services/kafkaconnect.html#KafkaConnect)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.1.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-kafkaconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafkaconnect/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-kafkaconnect](#mypy-boto3-kafkaconnect)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `KafkaConnect` service.

```bash
python -m pip install boto3-stubs[kafkaconnect]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kafkaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[kafkaconnect]'`

Both type checking and auto-complete should work for `KafkaConnect` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[kafkaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[kafkaconnect]'`

Both type checking and auto-complete should work for `KafkaConnect` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kafkaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[kafkaconnect]'`
- Run `mypy` as usual

Type checking should work for `KafkaConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kafkaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[kafkaconnect]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `KafkaConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`KafkaConnectClient` provides annotations for `boto3.client("kafkaconnect")`.

```python
import boto3

from mypy_boto3_kafkaconnect import KafkaConnectClient

client: KafkaConnectClient = boto3.client("kafkaconnect")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: KafkaConnectClient = session.client("kafkaconnect")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_kafkaconnect.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_kafkaconnect import KafkaConnectClient
from mypy_boto3_kafkaconnect.paginator import (
    ListConnectorsPaginator,
    ListCustomPluginsPaginator,
    ListWorkerConfigurationsPaginator,
)

client: KafkaConnectClient = boto3.client("kafkaconnect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_connectors_paginator: ListConnectorsPaginator = client.get_paginator("list_connectors")
list_custom_plugins_paginator: ListCustomPluginsPaginator = client.get_paginator("list_custom_plugins")
list_worker_configurations_paginator: ListWorkerConfigurationsPaginator = client.get_paginator("list_worker_configurations")
```

<a id="literals"></a>

### Literals

`mypy_boto3_kafkaconnect.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_kafkaconnect.literals import (
    ConnectorStateType,
    CustomPluginContentTypeType,
    CustomPluginStateType,
    KafkaClusterClientAuthenticationTypeType,
    KafkaClusterEncryptionInTransitTypeType,
    ListConnectorsPaginatorName,
    ListCustomPluginsPaginatorName,
    ListWorkerConfigurationsPaginatorName,
    ServiceName,
    PaginatorName,
)

def check_value(value: ConnectorStateType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_kafkaconnect.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_kafkaconnect.type_defs import (
    ApacheKafkaClusterDescriptionTypeDef,
    ApacheKafkaClusterTypeDef,
    AutoScalingDescriptionTypeDef,
    AutoScalingTypeDef,
    AutoScalingUpdateTypeDef,
    CapacityDescriptionTypeDef,
    CapacityTypeDef,
    CapacityUpdateTypeDef,
    CloudWatchLogsLogDeliveryDescriptionTypeDef,
    CloudWatchLogsLogDeliveryTypeDef,
    ConnectorSummaryTypeDef,
    CreateConnectorRequestRequestTypeDef,
    CreateConnectorResponseTypeDef,
    CreateCustomPluginRequestRequestTypeDef,
    CreateCustomPluginResponseTypeDef,
    CreateWorkerConfigurationRequestRequestTypeDef,
    CreateWorkerConfigurationResponseTypeDef,
    CustomPluginDescriptionTypeDef,
    CustomPluginFileDescriptionTypeDef,
    CustomPluginLocationDescriptionTypeDef,
    CustomPluginLocationTypeDef,
    CustomPluginRevisionSummaryTypeDef,
    CustomPluginSummaryTypeDef,
    CustomPluginTypeDef,
    DeleteConnectorRequestRequestTypeDef,
    DeleteConnectorResponseTypeDef,
    DescribeConnectorRequestRequestTypeDef,
    DescribeConnectorResponseTypeDef,
    DescribeCustomPluginRequestRequestTypeDef,
    DescribeCustomPluginResponseTypeDef,
    DescribeWorkerConfigurationRequestRequestTypeDef,
    DescribeWorkerConfigurationResponseTypeDef,
    FirehoseLogDeliveryDescriptionTypeDef,
    FirehoseLogDeliveryTypeDef,
    KafkaClusterClientAuthenticationDescriptionTypeDef,
    KafkaClusterClientAuthenticationTypeDef,
    KafkaClusterDescriptionTypeDef,
    KafkaClusterEncryptionInTransitDescriptionTypeDef,
    KafkaClusterEncryptionInTransitTypeDef,
    KafkaClusterTypeDef,
    ListConnectorsRequestRequestTypeDef,
    ListConnectorsResponseTypeDef,
    ListCustomPluginsRequestRequestTypeDef,
    ListCustomPluginsResponseTypeDef,
    ListWorkerConfigurationsRequestRequestTypeDef,
    ListWorkerConfigurationsResponseTypeDef,
    LogDeliveryDescriptionTypeDef,
    LogDeliveryTypeDef,
    PaginatorConfigTypeDef,
    PluginDescriptionTypeDef,
    PluginTypeDef,
    ProvisionedCapacityDescriptionTypeDef,
    ProvisionedCapacityTypeDef,
    ProvisionedCapacityUpdateTypeDef,
    ResponseMetadataTypeDef,
    S3LocationDescriptionTypeDef,
    S3LocationTypeDef,
    S3LogDeliveryDescriptionTypeDef,
    S3LogDeliveryTypeDef,
    ScaleInPolicyDescriptionTypeDef,
    ScaleInPolicyTypeDef,
    ScaleInPolicyUpdateTypeDef,
    ScaleOutPolicyDescriptionTypeDef,
    ScaleOutPolicyTypeDef,
    ScaleOutPolicyUpdateTypeDef,
    UpdateConnectorRequestRequestTypeDef,
    UpdateConnectorResponseTypeDef,
    VpcDescriptionTypeDef,
    VpcTypeDef,
    WorkerConfigurationDescriptionTypeDef,
    WorkerConfigurationRevisionDescriptionTypeDef,
    WorkerConfigurationRevisionSummaryTypeDef,
    WorkerConfigurationSummaryTypeDef,
    WorkerConfigurationTypeDef,
    WorkerLogDeliveryDescriptionTypeDef,
    WorkerLogDeliveryTypeDef,
)

def get_structure() -> ApacheKafkaClusterDescriptionTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-kafkaconnect` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-kafkaconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafkaconnect/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
